@@ -16,7 +16,7 @@
 #define PUT(emitter,value)                                                      \
     (FLUSH(emitter)                                                             \
      && (*(emitter->buffer.pointer++) = (yaml_char_t)(value),                   \
-         emitter->column++,                                             	\
+         emitter->column ++,                                                    \
          1))
 
 /*
@@ -517,7 +517,7 @@ yaml_emitter_emit_stream_start(yaml_emitter_t *emitter,
         if (emitter->best_width < 0) {
             emitter->best_width = INT_MAX;
         }
-        
+
         if (!emitter->line_break) {
             emitter->line_break = YAML_LN_BREAK;
         }
@@ -607,7 +607,7 @@ yaml_emitter_emit_document_start(yaml_emitter_t *emitter,
             if (!yaml_emitter_write_indent(emitter))
                 return 0;
         }
-        
+
         if (event->data.document_start.tag_directives.start
                 != event->data.document_start.tag_directives.end) {
             implicit = 0;
@@ -706,7 +706,7 @@ yaml_emitter_emit_document_end(yaml_emitter_t *emitter,
 
         emitter->state = YAML_EMIT_DOCUMENT_START_STATE;
 
-        while (!(STACK_EMPTY(emitter, emitter->tag_directives))) {
+        while (!STACK_EMPTY(emitter, emitter->tag_directives)) {
             yaml_tag_directive_t tag_directive = POP(emitter,
                     emitter->tag_directives);
             yaml_free(tag_directive.handle);
@@ -721,7 +721,7 @@ yaml_emitter_emit_document_end(yaml_emitter_t *emitter,
 }
 
 /*
- * 
+ *
  * Expect a flow item node.
  */
 
@@ -869,7 +869,7 @@ yaml_emitter_emit_block_sequence_item(yaml_emitter_t *emitter,
     if (first)
     {
         if (!yaml_emitter_increase_indent(emitter, 0,
-            emitter->indentless_map && (emitter->mapping_context && !emitter->indention)))
+                    (emitter->mapping_context && !emitter->indention)))
             return 0;
     }
 
@@ -993,6 +993,8 @@ yaml_emitter_emit_node(yaml_emitter_t *emitter, yaml_event_t *event,
             return yaml_emitter_set_emitter_error(emitter,
                     "expected SCALAR, SEQUENCE-START, MAPPING-START, or ALIAS");
     }
+
+    return 0;
 }
 
 /*
@@ -1400,7 +1402,7 @@ yaml_emitter_analyze_anchor(yaml_emitter_t *emitter,
 {
     size_t anchor_length;
     yaml_string_t string;
-    
+
     anchor_length = strlen((char *)anchor);
     STRING_ASSIGN(string, anchor, anchor_length);
 
@@ -1491,7 +1493,7 @@ yaml_emitter_analyze_scalar(yaml_emitter_t *emitter,
     int break_space = 0;
     int space_break = 0;
 
-    int preceeded_by_whitespace = 0;
+    int preceded_by_whitespace = 0;
     int followed_by_whitespace = 0;
     int previous_space = 0;
     int previous_break = 0;
@@ -1522,7 +1524,7 @@ yaml_emitter_analyze_scalar(yaml_emitter_t *emitter,
         flow_indicators = 1;
     }
 
-    preceeded_by_whitespace = 1;
+    preceded_by_whitespace = 1;
     followed_by_whitespace = IS_BLANKZ_AT(string, WIDTH(string));
 
     while (string.pointer != string.end)
@@ -1568,7 +1570,7 @@ yaml_emitter_analyze_scalar(yaml_emitter_t *emitter,
                 }
             }
 
-            if (CHECK(string, '#') && preceeded_by_whitespace) {
+            if (CHECK(string, '#') && preceded_by_whitespace) {
                 flow_indicators = 1;
                 block_indicators = 1;
             }
@@ -1617,7 +1619,7 @@ yaml_emitter_analyze_scalar(yaml_emitter_t *emitter,
             previous_break = 0;
         }
 
-        preceeded_by_whitespace = IS_BLANKZ(string);
+        preceded_by_whitespace = IS_BLANKZ(string);
         MOVE(string);
         if (string.pointer != string.end) {
             followed_by_whitespace = IS_BLANKZ_AT(string, WIDTH(string));
@@ -1751,8 +1753,7 @@ yaml_emitter_analyze_event(yaml_emitter_t *emitter,
 static int
 yaml_emitter_write_bom(yaml_emitter_t *emitter)
 {
-    if (!FLUSH(emitter))
-        return 0;
+    if (!FLUSH(emitter)) return 0;
 
     *(emitter->buffer.pointer++) = (yaml_char_t) '\xEF';
     *(emitter->buffer.pointer++) = (yaml_char_t) '\xBB';
@@ -1768,13 +1769,11 @@ yaml_emitter_write_indent(yaml_emitter_t *emitter)
 
     if (!emitter->indention || emitter->column > indent
             || (emitter->column == indent && !emitter->whitespace)) {
-        if (!PUT_BREAK(emitter))
-            return 0;
+        if (!PUT_BREAK(emitter)) return 0;
     }
 
     while (emitter->column < indent) {
-        if (!PUT(emitter, ' '))
-            return 0;
+        if (!PUT(emitter, ' ')) return 0;
     }
 
     emitter->whitespace = 1;
@@ -1795,13 +1794,11 @@ yaml_emitter_write_indicator(yaml_emitter_t *emitter,
     STRING_ASSIGN(string, (yaml_char_t *)indicator, indicator_length);
 
     if (need_whitespace && !emitter->whitespace) {
-        if (!PUT(emitter, ' '))
-            return 0;
+        if (!PUT(emitter, ' ')) return 0;
     }
 
     while (string.pointer != string.end) {
-        if (!WRITE(emitter, string))
-            return 0;
+        if (!WRITE(emitter, string)) return 0;
     }
 
     emitter->whitespace = is_whitespace;
@@ -1819,8 +1816,7 @@ yaml_emitter_write_anchor(yaml_emitter_t *emitter,
     STRING_ASSIGN(string, value, length);
 
     while (string.pointer != string.end) {
-        if (!WRITE(emitter, string))
-            return 0;
+        if (!WRITE(emitter, string)) return 0;
     }
 
     emitter->whitespace = 0;
@@ -1837,13 +1833,11 @@ yaml_emitter_write_tag_handle(yaml_emitter_t *emitter,
     STRING_ASSIGN(string, value, length);
 
     if (!emitter->whitespace) {
-        if (!PUT(emitter, ' '))
-            return 0;
+        if (!PUT(emitter, ' ')) return 0;
     }
 
     while (string.pointer != string.end) {
-        if (!WRITE(emitter, string))
-            return 0;
+        if (!WRITE(emitter, string)) return 0;
     }
 
     emitter->whitespace = 0;
@@ -1861,8 +1855,7 @@ yaml_emitter_write_tag_content(yaml_emitter_t *emitter,
     STRING_ASSIGN(string, value, length);
 
     if (need_whitespace && !emitter->whitespace) {
-        if (!PUT(emitter, ' '))
-            return 0;
+        if (!PUT(emitter, ' ')) return 0;
     }
 
     while (string.pointer != string.end) {
@@ -1877,21 +1870,19 @@ yaml_emitter_write_tag_content(yaml_emitter_t *emitter,
                 || CHECK(string, '\'') || CHECK(string, '(')
                 || CHECK(string, ')') || CHECK(string, '[')
                 || CHECK(string, ']')) {
-            if (!WRITE(emitter, string))
-                return 0;
+            if (!WRITE(emitter, string)) return 0;
         }
         else {
             int width = WIDTH(string);
-            unsigned int v;
+            unsigned int value;
             while (width --) {
-                v = *(string.pointer++);
-                if (!PUT(emitter, '%'))
+                value = *(string.pointer++);
+                if (!PUT(emitter, '%')) return 0;
+                if (!PUT(emitter, (value >> 4)
+                            + ((value >> 4) < 10 ? '0' : 'A' - 10)))
                     return 0;
-                if (!PUT(emitter, (v >> 4)
-                               + ((v >> 4) < 10 ? '0' : 'A' - 10)))
-                    return 0;
-                if (!PUT(emitter, (v & 0x0F)
-                               + ((v & 0x0F) < 10 ? '0' : 'A' - 10)))
+                if (!PUT(emitter, (value & 0x0F)
+                            + ((value & 0x0F) < 10 ? '0' : 'A' - 10)))
                     return 0;
             }
         }
@@ -1914,45 +1905,39 @@ yaml_emitter_write_plain_scalar(yaml_emitter_t *emitter,
     STRING_ASSIGN(string, value, length);
 
     if (!emitter->whitespace) {
-        if (!PUT(emitter, ' '))
-            return 0;
+        if (!PUT(emitter, ' ')) return 0;
     }
 
     while (string.pointer != string.end)
     {
-        if (IS_SPACE(string)) {
-            if (allow_breaks
-                && !spaces
-                && emitter->column > emitter->best_width
-                && !(IS_SPACE_AT(string, 1)))
-            {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+        if (IS_SPACE(string))
+        {
+            if (allow_breaks && !spaces
+                    && emitter->column > emitter->best_width
+                    && !IS_SPACE_AT(string, 1)) {
+                if (!yaml_emitter_write_indent(emitter)) return 0;
                 MOVE(string);
             }
             else {
-                if (!WRITE(emitter, string))
-                    return 0;
+                if (!WRITE(emitter, string)) return 0;
             }
             spaces = 1;
         }
-        else if (IS_BREAK(string)) {
+        else if (IS_BREAK(string))
+        {
             if (!breaks && CHECK(string, '\n')) {
-                if (!PUT_BREAK(emitter))
-                    return 0;
+                if (!PUT_BREAK(emitter)) return 0;
             }
-            if (!WRITE_BREAK(emitter, string))
-                return 0;
+            if (!WRITE_BREAK(emitter, string)) return 0;
             emitter->indention = 1;
             breaks = 1;
         }
-        else {
+        else
+        {
             if (breaks) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
             }
-            if (!WRITE(emitter, string))
-                return 0;
+            if (!WRITE(emitter, string)) return 0;
             emitter->indention = 0;
             spaces = 0;
             breaks = 0;
@@ -1961,15 +1946,6 @@ yaml_emitter_write_plain_scalar(yaml_emitter_t *emitter,
 
     emitter->whitespace = 0;
     emitter->indention = 0;
-/*
- * < rz> ingy: i'm not sure why i set open_ended in yaml_emitter_write_plain_scalar
- *
- * Disabling this as it breaks YAML::XS tests with no perceived benefit.
- *     if (emitter->root_context)
- *     {
- *         emitter->open_ended = 1;
- *     }
- */
 
     return 1;
 }
@@ -1989,46 +1965,39 @@ yaml_emitter_write_single_quoted_scalar(yaml_emitter_t *emitter,
 
     while (string.pointer != string.end)
     {
-        if (IS_SPACE(string)) {
-            if (allow_breaks
-                && !spaces
-                && emitter->column > emitter->best_width
-                && string.pointer != string.start
-                && string.pointer != string.end - 1
-                && !(IS_SPACE_AT(string, 1)))
-            {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+        if (IS_SPACE(string))
+        {
+            if (allow_breaks && !spaces
+                    && emitter->column > emitter->best_width
+                    && string.pointer != string.start
+                    && string.pointer != string.end - 1
+                    && !IS_SPACE_AT(string, 1)) {
+                if (!yaml_emitter_write_indent(emitter)) return 0;
                 MOVE(string);
             }
             else {
-                if (!WRITE(emitter, string))
-                    return 0;
+                if (!WRITE(emitter, string)) return 0;
             }
             spaces = 1;
         }
-        else if (IS_BREAK(string)) {
+        else if (IS_BREAK(string))
+        {
             if (!breaks && CHECK(string, '\n')) {
-                if (!PUT_BREAK(emitter))
-                    return 0;
+                if (!PUT_BREAK(emitter)) return 0;
             }
-            if (!WRITE_BREAK(emitter, string))
-                return 0;
+            if (!WRITE_BREAK(emitter, string)) return 0;
             emitter->indention = 1;
             breaks = 1;
         }
         else
         {
             if (breaks) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
             }
             if (CHECK(string, '\'')) {
-                if (!PUT(emitter, '\''))
-                    return 0;
+                if (!PUT(emitter, '\'')) return 0;
             }
-            if (!WRITE(emitter, string))
-                return 0;
+            if (!WRITE(emitter, string)) return 0;
             emitter->indention = 0;
             spaces = 0;
             breaks = 0;
@@ -2064,7 +2033,7 @@ yaml_emitter_write_double_quoted_scalar(yaml_emitter_t *emitter,
         {
             unsigned char octet;
             unsigned int width;
-            unsigned int v;
+            unsigned int value;
             int k;
 
             octet = string.pointer[0];
@@ -2072,142 +2041,121 @@ yaml_emitter_write_double_quoted_scalar(yaml_emitter_t *emitter,
                     (octet & 0xE0) == 0xC0 ? 2 :
                     (octet & 0xF0) == 0xE0 ? 3 :
                     (octet & 0xF8) == 0xF0 ? 4 : 0;
-            v     = (octet & 0x80) == 0x00 ? octet & 0x7F :
+            value = (octet & 0x80) == 0x00 ? octet & 0x7F :
                     (octet & 0xE0) == 0xC0 ? octet & 0x1F :
                     (octet & 0xF0) == 0xE0 ? octet & 0x0F :
                     (octet & 0xF8) == 0xF0 ? octet & 0x07 : 0;
             for (k = 1; k < (int)width; k ++) {
                 octet = string.pointer[k];
-                v     = (v << 6) + (octet & 0x3F);
+                value = (value << 6) + (octet & 0x3F);
             }
             string.pointer += width;
 
-            if (!PUT(emitter, '\\'))
-                return 0;
+            if (!PUT(emitter, '\\')) return 0;
 
-            switch (v)
+            switch (value)
             {
                 case 0x00:
-                    if (!PUT(emitter, '0'))
-                        return 0;
+                    if (!PUT(emitter, '0')) return 0;
                     break;
 
                 case 0x07:
-                    if (!PUT(emitter, 'a'))
-                        return 0;
+                    if (!PUT(emitter, 'a')) return 0;
                     break;
 
                 case 0x08:
-                    if (!PUT(emitter, 'b'))
-                        return 0;
+                    if (!PUT(emitter, 'b')) return 0;
                     break;
 
                 case 0x09:
-                    if (!PUT(emitter, 't'))
-                        return 0;
+                    if (!PUT(emitter, 't')) return 0;
                     break;
 
                 case 0x0A:
-                    if (!PUT(emitter, 'n'))
-                        return 0;
+                    if (!PUT(emitter, 'n')) return 0;
                     break;
 
                 case 0x0B:
-                    if (!PUT(emitter, 'v'))
-                        return 0;
+                    if (!PUT(emitter, 'v')) return 0;
                     break;
 
                 case 0x0C:
-                    if (!PUT(emitter, 'f'))
-                        return 0;
+                    if (!PUT(emitter, 'f')) return 0;
                     break;
 
                 case 0x0D:
-                    if (!PUT(emitter, 'r'))
-                        return 0;
+                    if (!PUT(emitter, 'r')) return 0;
                     break;
 
                 case 0x1B:
-                    if (!PUT(emitter, 'e'))
-                        return 0;
+                    if (!PUT(emitter, 'e')) return 0;
                     break;
 
                 case 0x22:
-                    if (!PUT(emitter, '\"'))
-                        return 0;
+                    if (!PUT(emitter, '\"')) return 0;
                     break;
 
                 case 0x5C:
-                    if (!PUT(emitter, '\\'))
-                        return 0;
+                    if (!PUT(emitter, '\\')) return 0;
                     break;
 
                 case 0x85:
-                    if (!PUT(emitter, 'N'))
-                        return 0;
+                    if (!PUT(emitter, 'N')) return 0;
                     break;
 
                 case 0xA0:
-                    if (!PUT(emitter, '_'))
-                        return 0;
+                    if (!PUT(emitter, '_')) return 0;
                     break;
 
                 case 0x2028:
-                    if (!PUT(emitter, 'L'))
-                        return 0;
+                    if (!PUT(emitter, 'L')) return 0;
                     break;
 
                 case 0x2029:
-                    if (!PUT(emitter, 'P'))
-                        return 0;
+                    if (!PUT(emitter, 'P')) return 0;
                     break;
 
                 default:
-                    if (v <= 0xFF) {
-                        if (!PUT(emitter, 'x'))
-                            return 0;
+                    if (value <= 0xFF) {
+                        if (!PUT(emitter, 'x')) return 0;
                         width = 2;
                     }
-                    else if (v <= 0xFFFF) {
-                        if (!PUT(emitter, 'u'))
-                            return 0;
+                    else if (value <= 0xFFFF) {
+                        if (!PUT(emitter, 'u')) return 0;
                         width = 4;
                     }
                     else {
-                        if (!PUT(emitter, 'U'))
-                            return 0;
+                        if (!PUT(emitter, 'U')) return 0;
                         width = 8;
                     }
                     for (k = (width-1)*4; k >= 0; k -= 4) {
-                        int digit = (v >> k) & 0x0F;
+                        int digit = (value >> k) & 0x0F;
                         if (!PUT(emitter, digit + (digit < 10 ? '0' : 'A'-10)))
                             return 0;
                     }
             }
             spaces = 0;
         }
-        else if (IS_SPACE(string)) {
+        else if (IS_SPACE(string))
+        {
             if (allow_breaks && !spaces
                     && emitter->column > emitter->best_width
                     && string.pointer != string.start
                     && string.pointer != string.end - 1) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
                 if (IS_SPACE_AT(string, 1)) {
-                    if (!PUT(emitter, '\\'))
-                        return 0;
+                    if (!PUT(emitter, '\\')) return 0;
                 }
                 MOVE(string);
             }
             else {
-                if (!WRITE(emitter, string))
-                    return 0;
+                if (!WRITE(emitter, string)) return 0;
             }
             spaces = 1;
         }
-        else {
-            if (!WRITE(emitter, string))
-                return 0;
+        else
+        {
+            if (!WRITE(emitter, string)) return 0;
             spaces = 0;
         }
     }
@@ -2228,7 +2176,8 @@ yaml_emitter_write_block_scalar_hints(yaml_emitter_t *emitter,
     char indent_hint[2];
     char *chomp_hint = NULL;
 
-    if (IS_SPACE(string) || IS_BREAK(string)) {
+    if (IS_SPACE(string) || IS_BREAK(string))
+    {
         indent_hint[0] = '0' + (char)emitter->best_indent;
         indent_hint[1] = '\0';
         if (!yaml_emitter_write_indicator(emitter, indent_hint, 0, 0, 0))
@@ -2238,32 +2187,39 @@ yaml_emitter_write_block_scalar_hints(yaml_emitter_t *emitter,
     emitter->open_ended = 0;
 
     string.pointer = string.end;
-    if (string.start == string.pointer) {
+    if (string.start == string.pointer)
+    {
         chomp_hint = "-";
     }
-    else {
+    else
+    {
         do {
             string.pointer --;
         } while ((*string.pointer & 0xC0) == 0x80);
-        if (!IS_BREAK(string)) {
+        if (!IS_BREAK(string))
+        {
             chomp_hint = "-";
         }
-        else if (string.start == string.pointer) {
+        else if (string.start == string.pointer)
+        {
             chomp_hint = "+";
             emitter->open_ended = 1;
         }
-        else {
+        else
+        {
             do {
                 string.pointer --;
             } while ((*string.pointer & 0xC0) == 0x80);
-            if (IS_BREAK(string)) {
+            if (IS_BREAK(string))
+            {
                 chomp_hint = "+";
                 emitter->open_ended = 1;
             }
         }
     }
 
-    if (chomp_hint) {
+    if (chomp_hint)
+    {
         if (!yaml_emitter_write_indicator(emitter, chomp_hint, 0, 0, 0))
             return 0;
     }
@@ -2284,8 +2240,7 @@ yaml_emitter_write_literal_scalar(yaml_emitter_t *emitter,
         return 0;
     if (!yaml_emitter_write_block_scalar_hints(emitter, string))
         return 0;
-    if (!PUT_BREAK(emitter))
-        return 0;
+    if (!PUT_BREAK(emitter)) return 0;
     emitter->indention = 1;
     emitter->whitespace = 1;
 
@@ -2293,19 +2248,16 @@ yaml_emitter_write_literal_scalar(yaml_emitter_t *emitter,
     {
         if (IS_BREAK(string))
         {
-            if (!WRITE_BREAK(emitter, string))
-                return 0;
+            if (!WRITE_BREAK(emitter, string)) return 0;
             emitter->indention = 1;
             breaks = 1;
         }
         else
         {
             if (breaks) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
             }
-            if (!WRITE(emitter, string))
-                        return 0;
+            if (!WRITE(emitter, string)) return 0;
             emitter->indention = 0;
             breaks = 0;
         }
@@ -2328,8 +2280,7 @@ yaml_emitter_write_folded_scalar(yaml_emitter_t *emitter,
         return 0;
     if (!yaml_emitter_write_block_scalar_hints(emitter, string))
         return 0;
-    if (!PUT_BREAK(emitter))
-        return 0;
+    if (!PUT_BREAK(emitter)) return 0;
     emitter->indention = 1;
     emitter->whitespace = 1;
 
@@ -2343,31 +2294,26 @@ yaml_emitter_write_folded_scalar(yaml_emitter_t *emitter,
                     k += WIDTH_AT(string, k);
                 }
                 if (!IS_BLANKZ_AT(string, k)) {
-                    if (!PUT_BREAK(emitter))
-                        return 0;
+                    if (!PUT_BREAK(emitter)) return 0;
                 }
             }
-            if (!WRITE_BREAK(emitter, string))
-                return 0;
+            if (!WRITE_BREAK(emitter, string)) return 0;
             emitter->indention = 1;
             breaks = 1;
         }
         else
         {
             if (breaks) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
                 leading_spaces = IS_BLANK(string);
             }
-            if (!breaks && IS_SPACE(string) && !(IS_SPACE_AT(string, 1))
+            if (!breaks && IS_SPACE(string) && !IS_SPACE_AT(string, 1)
                     && emitter->column > emitter->best_width) {
-                if (!yaml_emitter_write_indent(emitter))
-                    return 0;
+                if (!yaml_emitter_write_indent(emitter)) return 0;
                 MOVE(string);
             }
             else {
-                if (!WRITE(emitter, string))
-                    return 0;
+                if (!WRITE(emitter, string)) return 0;
             }
             emitter->indention = 0;
             breaks = 0;
@@ -2376,4 +2322,3 @@ yaml_emitter_write_folded_scalar(yaml_emitter_t *emitter,
 
     return 1;
 }
-
